#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = __importDefault(require("commander"));
const fs_1 = __importDefault(require("fs"));
const shelljs_1 = __importDefault(require("shelljs"));
const package_json_1 = require("../package.json");
const jetbrains_1 = require("./jetbrains");
commander_1.default
    .version(package_json_1.version)
    .description(`
    open a project using a JetBrains IDE

    Available IDEs: ${jetbrains_1.availableIdes().join(', ')}
    `)
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    let directory = commander_1.default.args[0] || '.';
    if (directory === '.') {
        directory = process.cwd();
    }
    try {
        const files = fs_1.default.readdirSync(directory);
        const ideTarget = jetbrains_1.determineJetbrainsIDE(files);
        const applicationPath = shelljs_1.default.ls('-d', `/Applications/${ideTarget.ide}*`).pop();
        if (!applicationPath) {
            process.stdout.write(chalk_1.default.red(`Unable to find ${ideTarget.ide} application`));
            process.exit(1);
        }
        process.stdout.write(chalk_1.default.green(`opening with ${applicationPath}`));
        const command = `open -a "${applicationPath}" "${ideTarget.target}"`;
        yield new Promise((resolve, reject) => shelljs_1.default.exec(command, {}, (code, stdout, stderr) => {
            if (stderr) {
                return reject(stderr);
            }
            resolve(stdout);
        }));
    }
    catch (e) {
        process.stderr.write(chalk_1.default.bold.red(e.message));
    }
}));
commander_1.default.parse(process.argv);
//# sourceMappingURL=index.js.map