"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var IDEs;
(function (IDEs) {
    IDEs["PHPStorm"] = "PhpStorm";
    IDEs["WebStorm"] = "WebStorm";
    IDEs["IntelliJ"] = "IntelliJ";
    IDEs["GoLand"] = "GoLand";
    IDEs["CLion"] = "CLion";
})(IDEs || (IDEs = {}));
const isProjectFile = (file) => {
    const projectFilePatterns = [/pom\.xml/, /\.ipr/, /build\.xml/, /\.idea/];
    let isMatching = false;
    projectFilePatterns.forEach(p => (isMatching = isMatching || p.test(file)));
    return isMatching;
};
const isWebStormFile = (file) => [
    'package.json',
    'bower.json',
    'gulpfile.json',
    'gruntfile.json',
].includes(file);
const isPhpStormFile = (file) => [
    'composer.json'
].includes(file);
const isGoLandFile = (file) => [
    'go.mod',
    'main.go',
    'Gopkg.lock'
].includes(file);
const isCLionFile = (file) => [
    'platformio.ini'
].includes(file);
const reduceProjectFiles = (files) => files.reduce((acc, f) => ({
    hasCLionFiles: acc.hasCLionFiles || isCLionFile(f),
    hasGoLandFiles: acc.hasGoLandFiles || isGoLandFile(f),
    hasPhpStormFiles: acc.hasPhpStormFiles || isPhpStormFile(f),
    hasWebStormFiles: acc.hasWebStormFiles || isWebStormFile(f),
    projectFile: acc.projectFile || (isProjectFile(f) ? f : null),
}), {
    hasCLionFiles: false,
    hasGoLandFiles: false,
    hasPhpStormFiles: false,
    hasWebStormFiles: false,
    projectFile: null,
});
const convertProjectFilesToAppName = (projectFiles) => {
    if (projectFiles.hasPhpStormFiles) {
        return IDEs.PHPStorm;
    }
    else if (projectFiles.hasGoLandFiles) {
        return IDEs.GoLand;
    }
    else if (projectFiles.hasCLionFiles) {
        return IDEs.CLion;
    }
    else if (projectFiles.hasWebStormFiles) {
        return IDEs.WebStorm;
    }
    else {
        return IDEs.IntelliJ;
    }
};
exports.determineJetbrainsIDE = (projectFiles) => {
    const projectStat = reduceProjectFiles(projectFiles);
    const ide = convertProjectFilesToAppName(projectStat);
    return {
        ide,
        target: projectStat.projectFile,
    };
};
exports.availableIdes = () => Object.values(IDEs);
//# sourceMappingURL=jetbrains.js.map